/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImportAddressBooks.idl
 */

#ifndef __gen_nsIImportAddressBooks_h__
#define __gen_nsIImportAddressBooks_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsISupportsArray; /* forward declaration */

class nsIImportABDescriptor; /* forward declaration */

class nsIOutputStream; /* forward declaration */

class nsIAddrDatabase; /* forward declaration */

class nsIImportFieldMap; /* forward declaration */


/* starting interface:    nsIImportAddressBooks */
#define NS_IIMPORTADDRESSBOOKS_IID_STR "49e2bdf8-c5c3-4425-8c67-f20d15d45a71"

#define NS_IIMPORTADDRESSBOOKS_IID \
  {0x49e2bdf8, 0xc5c3, 0x4425, \
    { 0x8c, 0x67, 0xf2, 0x0d, 0x15, 0xd4, 0x5a, 0x71 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIImportAddressBooks : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMPORTADDRESSBOOKS_IID)

  /* PRBool GetSupportsMultiple (); */
  NS_SCRIPTABLE NS_IMETHOD GetSupportsMultiple(PRBool *_retval NS_OUTPARAM) = 0;

  /* PRBool GetAutoFind (out wstring description); */
  NS_SCRIPTABLE NS_IMETHOD GetAutoFind(PRUnichar **description NS_OUTPARAM, PRBool *_retval NS_OUTPARAM) = 0;

  /* PRBool GetNeedsFieldMap (in nsIFile location); */
  NS_SCRIPTABLE NS_IMETHOD GetNeedsFieldMap(nsIFile *location, PRBool *_retval NS_OUTPARAM) = 0;

  /* void GetDefaultLocation (out nsIFile location, out boolean found, out boolean userVerify); */
  NS_SCRIPTABLE NS_IMETHOD GetDefaultLocation(nsIFile **location NS_OUTPARAM, PRBool *found NS_OUTPARAM, PRBool *userVerify NS_OUTPARAM) = 0;

  /* nsISupportsArray FindAddressBooks (in nsIFile location); */
  NS_SCRIPTABLE NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray **_retval NS_OUTPARAM) = 0;

  /* void InitFieldMap (in nsIImportFieldMap fieldMap); */
  NS_SCRIPTABLE NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap) = 0;

  /**
   * Import a specific mailbox into the destination file supplied.  If an error
   * occurs that is non-fatal, the destination will be deleted and other
   * mailbox's will be imported.  If a fatal error occurs, the destination will
   * be deleted and the import operation will abort.
   *
   * @param aSource         The source data for the import.
   * @param aDestination    The proxy database for the destination of the
   *                        import.
   * @param aFieldMap       The field map containing the mapping of fields to be
   *                        used in cvs and tab type imports.
   * @param aSupportService An optional proxy support service (nsnull is
   *                        acceptable if it is not required), may be required
   *                        for certain import types (e.g. nsIAbLDIFService for
   *                        LDIF import).
   * @param aIsAddrLocHome  Whether or not an address is the home location.
   * @param aErrorLog       The error log from the import.
   * @param aSuccessLog     The success log from the import.
   * @param aFatalError     True if there was a fatal error doing the import.
   */
  /* void ImportAddressBook (in nsIImportABDescriptor aSource, in nsIAddrDatabase aDestination, in nsIImportFieldMap aFieldMap, in nsISupports aSupportService, in boolean aIsAddrLocHome, out wstring aErrorLog, out wstring aSuccessLog, out boolean aFatalError); */
  NS_SCRIPTABLE NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRBool aIsAddrLocHome, PRUnichar **aErrorLog NS_OUTPARAM, PRUnichar **aSuccessLog NS_OUTPARAM, PRBool *aFatalError NS_OUTPARAM) = 0;

  /* unsigned long GetImportProgress (); */
  NS_SCRIPTABLE NS_IMETHOD GetImportProgress(PRUint32 *_retval NS_OUTPARAM) = 0;

  /* void SetSampleLocation (in nsIFile location); */
  NS_SCRIPTABLE NS_IMETHOD SetSampleLocation(nsIFile *location) = 0;

  /* wstring GetSampleData (in long recordNumber, out boolean recordExists); */
  NS_SCRIPTABLE NS_IMETHOD GetSampleData(PRInt32 recordNumber, PRBool *recordExists NS_OUTPARAM, PRUnichar **_retval NS_OUTPARAM) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImportAddressBooks, NS_IIMPORTADDRESSBOOKS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTADDRESSBOOKS \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsMultiple(PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD GetAutoFind(PRUnichar **description NS_OUTPARAM, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD GetNeedsFieldMap(nsIFile *location, PRBool *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD GetDefaultLocation(nsIFile **location NS_OUTPARAM, PRBool *found NS_OUTPARAM, PRBool *userVerify NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap); \
  NS_SCRIPTABLE NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRBool aIsAddrLocHome, PRUnichar **aErrorLog NS_OUTPARAM, PRUnichar **aSuccessLog NS_OUTPARAM, PRBool *aFatalError NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD GetImportProgress(PRUint32 *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD SetSampleLocation(nsIFile *location); \
  NS_SCRIPTABLE NS_IMETHOD GetSampleData(PRInt32 recordNumber, PRBool *recordExists NS_OUTPARAM, PRUnichar **_retval NS_OUTPARAM); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTADDRESSBOOKS(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsMultiple(PRBool *_retval NS_OUTPARAM) { return _to GetSupportsMultiple(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetAutoFind(PRUnichar **description NS_OUTPARAM, PRBool *_retval NS_OUTPARAM) { return _to GetAutoFind(description, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetNeedsFieldMap(nsIFile *location, PRBool *_retval NS_OUTPARAM) { return _to GetNeedsFieldMap(location, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetDefaultLocation(nsIFile **location NS_OUTPARAM, PRBool *found NS_OUTPARAM, PRBool *userVerify NS_OUTPARAM) { return _to GetDefaultLocation(location, found, userVerify); } \
  NS_SCRIPTABLE NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray **_retval NS_OUTPARAM) { return _to FindAddressBooks(location, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap) { return _to InitFieldMap(fieldMap); } \
  NS_SCRIPTABLE NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRBool aIsAddrLocHome, PRUnichar **aErrorLog NS_OUTPARAM, PRUnichar **aSuccessLog NS_OUTPARAM, PRBool *aFatalError NS_OUTPARAM) { return _to ImportAddressBook(aSource, aDestination, aFieldMap, aSupportService, aIsAddrLocHome, aErrorLog, aSuccessLog, aFatalError); } \
  NS_SCRIPTABLE NS_IMETHOD GetImportProgress(PRUint32 *_retval NS_OUTPARAM) { return _to GetImportProgress(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD SetSampleLocation(nsIFile *location) { return _to SetSampleLocation(location); } \
  NS_SCRIPTABLE NS_IMETHOD GetSampleData(PRInt32 recordNumber, PRBool *recordExists NS_OUTPARAM, PRUnichar **_retval NS_OUTPARAM) { return _to GetSampleData(recordNumber, recordExists, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTADDRESSBOOKS(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetSupportsMultiple(PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportsMultiple(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetAutoFind(PRUnichar **description NS_OUTPARAM, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAutoFind(description, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetNeedsFieldMap(nsIFile *location, PRBool *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedsFieldMap(location, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetDefaultLocation(nsIFile **location NS_OUTPARAM, PRBool *found NS_OUTPARAM, PRBool *userVerify NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultLocation(location, found, userVerify); } \
  NS_SCRIPTABLE NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindAddressBooks(location, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitFieldMap(fieldMap); } \
  NS_SCRIPTABLE NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRBool aIsAddrLocHome, PRUnichar **aErrorLog NS_OUTPARAM, PRUnichar **aSuccessLog NS_OUTPARAM, PRBool *aFatalError NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->ImportAddressBook(aSource, aDestination, aFieldMap, aSupportService, aIsAddrLocHome, aErrorLog, aSuccessLog, aFatalError); } \
  NS_SCRIPTABLE NS_IMETHOD GetImportProgress(PRUint32 *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImportProgress(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD SetSampleLocation(nsIFile *location) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSampleLocation(location); } \
  NS_SCRIPTABLE NS_IMETHOD GetSampleData(PRInt32 recordNumber, PRBool *recordExists NS_OUTPARAM, PRUnichar **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSampleData(recordNumber, recordExists, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportAddressBooks : public nsIImportAddressBooks
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTADDRESSBOOKS

  nsImportAddressBooks();

private:
  ~nsImportAddressBooks();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportAddressBooks, nsIImportAddressBooks)

nsImportAddressBooks::nsImportAddressBooks()
{
  /* member initializers and constructor code */
}

nsImportAddressBooks::~nsImportAddressBooks()
{
  /* destructor code */
}

/* PRBool GetSupportsMultiple (); */
NS_IMETHODIMP nsImportAddressBooks::GetSupportsMultiple(PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* PRBool GetAutoFind (out wstring description); */
NS_IMETHODIMP nsImportAddressBooks::GetAutoFind(PRUnichar **description NS_OUTPARAM, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* PRBool GetNeedsFieldMap (in nsIFile location); */
NS_IMETHODIMP nsImportAddressBooks::GetNeedsFieldMap(nsIFile *location, PRBool *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void GetDefaultLocation (out nsIFile location, out boolean found, out boolean userVerify); */
NS_IMETHODIMP nsImportAddressBooks::GetDefaultLocation(nsIFile **location NS_OUTPARAM, PRBool *found NS_OUTPARAM, PRBool *userVerify NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISupportsArray FindAddressBooks (in nsIFile location); */
NS_IMETHODIMP nsImportAddressBooks::FindAddressBooks(nsIFile *location, nsISupportsArray **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void InitFieldMap (in nsIImportFieldMap fieldMap); */
NS_IMETHODIMP nsImportAddressBooks::InitFieldMap(nsIImportFieldMap *fieldMap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ImportAddressBook (in nsIImportABDescriptor aSource, in nsIAddrDatabase aDestination, in nsIImportFieldMap aFieldMap, in nsISupports aSupportService, in boolean aIsAddrLocHome, out wstring aErrorLog, out wstring aSuccessLog, out boolean aFatalError); */
NS_IMETHODIMP nsImportAddressBooks::ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRBool aIsAddrLocHome, PRUnichar **aErrorLog NS_OUTPARAM, PRUnichar **aSuccessLog NS_OUTPARAM, PRBool *aFatalError NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long GetImportProgress (); */
NS_IMETHODIMP nsImportAddressBooks::GetImportProgress(PRUint32 *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetSampleLocation (in nsIFile location); */
NS_IMETHODIMP nsImportAddressBooks::SetSampleLocation(nsIFile *location)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetSampleData (in long recordNumber, out boolean recordExists); */
NS_IMETHODIMP nsImportAddressBooks::GetSampleData(PRInt32 recordNumber, PRBool *recordExists NS_OUTPARAM, PRUnichar **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImportAddressBooks_h__ */
